@@ -7,7 +7,5 @@ class VdkOption(Enum):
     NAME = "jobName"
     TEAM = "jobTeam"
     PATH = "jobPath"
-    CLOUD = "cloud"
-    LOCAL = "local"
     ARGUMENTS = "jobArguments"
     DEPLOYMENT_REASON = "deploymentReason"
